@@ -1,14 +1,14 @@
 "descriptives.trait" <-
-function (data,subset,file,by=NULL,digits=3) {
+function (data,subset,file,by.var=NULL,digits=3) {
 	if (missing(data)) stop("data argument must be provided")
 	if (class(data) == "gwaa.data") data <- data@phdata
 	if (class(data) != "data.frame") stop("data argument must be of gwaa.data or data.frame-class")
 	len <- dim(data)[1]
 	ntra <- dim(data)[2]
 	if (!missing(subset)) data <- data[subset,]
-	if (!is.null(by)) {
-		svar <- by
-		if (length(unique(svar))!=2) stop("The by argument should contain a binary variable")
+	if (!is.null(by.var)) {
+		svar <- by.var
+		if (length(unique(svar))!=2) stop("The by.var argument should contain a binary variable")
 		out <- matrix(data=NA,nrow=ntra,ncol=9)
 		lvls <- unique(svar)
 		for (i in (1:ntra)) {
@@ -46,10 +46,10 @@ function (data,subset,file,by=NULL,digits=3) {
 	out <- round(out,digits=digits)
 	out <- data.frame(out)
 	rownames(out) <- colnames(data)
-	if (is.null(by)) 
+	if (is.null(by.var)) 
 		colnames(out) <- c("No","Mean","SD")
 	else 
-		colnames(out) <- c(paste("No(by=",lvls[1],")",sep=""),"Mean","SD",paste("No(by=",lvls[2],")",sep=""),"Mean","SD","Ptt","Pkw","Pexact")
+		colnames(out) <- c(paste("No(by.var=",lvls[1],")",sep=""),"Mean","SD",paste("No(by.var=",lvls[2],")",sep=""),"Mean","SD","Ptt","Pkw","Pexact")
 	if (!missing(file)) {
 		cat("\t",file=file,sep="")
 		cat(colnames(out),file=file,sep="\t",append=TRUE)
