@@ -152,7 +152,7 @@ res.boocc <- emp.ccfast("bt",data=srdta,snps=mymrk)
 min(res.boocc$P1df)
 plot(res.boocc)
 a<-readline("PRESS <Enter> TO CONTINUE...")
-res.score <- qtscore("bt~CRSNP",data=srdta,snps=mymrk)
+res.score <- qtscore(srdta@phdata$bt,data=srdta,snps=mymrk)
 min(res.score$P1df)
 -log10(min(res.score$P1df))
 which(res.score$P1df<=0.01)
@@ -163,13 +163,13 @@ points(res.score$map,-log10(res.score$P1df),col="red")
 a<-readline("PRESS <Enter> TO CONTINUE...")
 plot(res.fcc$P1df,res.score$P1df,pch=20)
 a<-readline("PRESS <Enter> TO CONTINUE...")
-res.score <- qtscore("bt ~ sex + age+CRSNP",data=srdta,snps=mymrk)
+res.score <- qtscore(bt ~ sex + age,data=srdta,snps=mymrk)
 min(res.score$P1df)
 -log10(min(res.score$P1df))
 which(res.score$P1df<=0.01)
 plot(res.score)
 a<-readline("PRESS <Enter> TO CONTINUE...")
-res.boosc <- emp.qtscore("bt~CRSNP",data=srdta,snps=mymrk)
+res.boosc <- emp.qtscore(srdta@phdata$bt,data=srdta,snps=mymrk)
 min(res.boosc$P1df)
 plot(res.boosc)
 a<-readline("PRESS <Enter> TO CONTINUE...")
@@ -252,21 +252,21 @@ attach(srdta@phdata)
 check.trait("qt2",data=srdta)
 summary(glm(qt2~age+sex))
 a<-readline("PRESS <Enter> TO CONTINUE...")
-r.qts <- qtscore("qt2~CRSNP",data=srdta,snps=mymrk)
+r.qts <- qtscore(srdta@phdata$qt2,data=srdta,snps=mymrk)
 min(r.qts$P1df)
 plot(r.qts)
 a<-readline("PRESS <Enter> TO CONTINUE...")
-r.qts <- qtscore("qt2~CRSNP",strata=srdta@phdata$sex,data=srdta,snps=mymrk)
+r.qts <- qtscore(srdta@phdata$qt2,strata=srdta@phdata$sex,data=srdta,snps=mymrk)
 min(r.qts$P1df)
 plot(r.qts)
 a<-readline("PRESS <Enter> TO CONTINUE...")
-r.aqts <- qtscore("qt2~age+sex+CRSNP",data=srdta,snps=mymrk)
+r.aqts <- qtscore(qt2~age+sex,data=srdta,snps=mymrk)
 min(r.aqts$P1df)
 which.min(r.aqts$P1df)
 plot(r.aqts)
 add.plot(r.aqts,col="red",cex=2.)
 a<-readline("PRESS <Enter> TO CONTINUE...")
-r.booqts <- emp.qtscore("qt2~age+sex+CRSNP",data=srdta,snps=mymrk,times=200)
+r.booqts <- emp.qtscore(qt2~age+sex,data=srdta,snps=mymrk,times=200)
 min(r.booqts$P1df)
 which.min(r.booqts$P1df)
 plot(r.booqts)
@@ -325,7 +325,7 @@ a<-readline("PRESS <Enter> TO CONTINUE...")
 #
 
 ?"figure out best SNP P-value"
-qts <- qtscore("qt2~sex+age+CRSNP",data=srdta)
+qts <- qtscore(qt2~sex+age,data=srdta)
 min(qts$P1df)
 
 ?"get index of the best SNP"
